==> spip_4.0.4.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_tout_compris' => 'Mouchañ holl kemennadoù ar c’heneil',
	'bouton_tout_compris_explication' => 'Ma anavezoc’h SPIP dija, e c’halloc’h divizout ober fae war holl kemenndoù ar c’heneil ; giz’all, pep kemenadenn a c’hall bezañ serret unan hag unan.',

	// C
	'c_accueil_bienvenue' => 'Degemer mat @nom@',
	'c_accueil_configurer_site' => 'Kefluniañ ho lec’h',
	'c_accueil_configurer_site_texte' => 'An dra gentañ d’ober eo reiñ un anv d’ho lec’hienn.
Bremañ ez eo anvet « @nom@ ». Dispaket eo an anv en nec’h d’ar bajenn-mañ.
En ur glikañ warnañ, e vo tu deoc’h kemmañ e anv, met ivez stagañ ul logo pe ul slogan warnañ.
		',
	'c_accueil_publication' => 'Embannit !',
	'c_accueil_publication_texte' => 'Evit embann ur bajenn e tleoc’h sevel ur pennad-skrid.
		Ret eo sevel ur rubrikenn d’an nebeutañ evit-se. Gallout a rit sevel unan e lañser "Embann" en ur klikañ war "Rubrikennoù".',
	'c_accueil_texte' => 'E lec’h prevez SPIP emaoc’h bremañ.',
	'c_accueil_texte_revenir' => '		Ar bajenn-mañ a ginnig ar pennadoù diwezhañ ho peus embannet war ho lec’h.
		Gallout a rit dont en-dro d’ar bajenn-mañ pep wech ho peus c’hoant en ur klikañ war ar skeuden "ti" a-hus, dindan hoc’h anv.
		',
	'c_article_redaction' => 'Ar pennad-mañ zo war-ober da skrivañ',
	'c_article_redaction_redacteur' => 'Ar pennad-mañ zo war-ober da skrivañ',
	'c_article_redaction_redacteur_texte' => 'Evit kinnig ho pennad-skrid da verourien ar lec’hienn ha d’ar re-all,
’barzh ar stern a gostez, kemmit « O skrivañ emer » gant « kinniget d’an embann ». ',
	'c_article_redaction_texte' => 'Evit embann ar pennad-mañ war al lec’h publik ret eo cheñch e statud.
		Er stern a-gostez chenchit "war-dro da skrivañ" en "embannet enlinenn".',
	'c_articles_creer' => 'Penaos krouiñ ur pennad-skrid ?',
	'c_articles_creer_texte' => 'Ne C’hallit ket krouiñ ur pennad-skrid er pajenn-mañ
		ma n’eus rubrikenn ebet en ho lec’h.
		Gallout a rit krouiñ anezhi el lañser "Embann", ha goude "Rubrikennoù" .',
	'c_job' => 'Labourioù da ober…',
	'c_job_texte' => 'Ar bajenn-mañ a sav roll al labourioù mererezh da vezañ kaset da benn gant SPIP. Al labourioù-maña vez a vez graet bep an amzer 
pe en un taol nemetken evit meriaduroù a-bouezh bet goulennet gant an astennoù plugin,
e-giz kas posteloù a-druilh-drast.',
	'c_rubrique_publier' => 'Krouit un embann skrid',
	'c_rubrique_publier_texte' => 'Ne vo gwelet ur rubrikenn war al lec’hienn foran
nemet pa vo  ur dra bennk embannet e-barzh ; dre skouer : ur pennad-skrid bet embannet.
Setu savit ur pennad-skrid. Tu zo en ober dre ar bajenn-mañ, dindan diskrivadenn ho rubrikenn.',
	'c_rubriques_creer' => 'Embannit ur rubrikenn gentañ !',
	'c_rubriques_creer_texte' => 'Framm al lec’h eo ar rubrikennoù ; galllout a rit krouiñ pennadoù-skrid e pep unan.
		Kinnig a rit krouiñ ur c’hentañ rubrikenn.',
	'c_sites_creer' => 'Penaos krouiñ pe enporzhiañ ul lec’h ?',
	'c_sites_creer_texte' => 'Ne c’hallit ket krouiñ pe enporzhiñ ul lec’h abaoe ar bajenn-mañ ma n’eus rubrikenn ebet en ho lec’h.
		Gallout a rit krouiñ anezhi el lañser "Embann", ha goude "Rubrikennoù".',

	// E
	'explication_activer_compagnon' => 'Ouzhpennañ a ra an ambrouger evezhiadennoù er pajennoù al lec’h prevez evit sikour ac’hanoc’h o implijout SPIP. Ezhomm hoc’h eus gweredekaet anezhañ ?',
	'explication_reinitialiser_compagnon' => 'Ne vez dispaket muioc’h ar gemenadennoù bet gwelet dija  gant un aozer.
C’hoant peus adkorañ ar gemenadennoù-se ?',

	// L
	'label_activer_compagnon' => 'Gweredekaat an ambrouger ?',
	'label_reinitialiser_compagnon' => 'Adreizhañ kannadoù an ambrouger ?',

	// O
	'ok' => 'Mat eo',
	'ok_bien' => 'Mat eo !',
	'ok_jai_compris' => 'komprennet em meus !',
	'ok_merci' => 'Trugarez',
	'ok_parfait' => 'Mat tre !',

	// R
	'reinitialisation' => 'Adkoradur',
	'reinitialisation_ok' => 'Echu eo an adkoradur.',
	'reinitialiser' => 'Adreizhet',
	'reinitialiser_moi' => 'Ya nemedken re meus dija lennet',
	'reinitialiser_tous' => 'Ya, sort pe sort vefe an aoser',

	// T
	'titre_compagnon' => 'An Ambrouger',
	'titre_page_configurer_compagnon' => 'Kefluniañ an Ambrouger'
);

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/compagnon/lang/compagnon_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compagnon?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_tout_compris' => 'Mouchañ holl kemennadoù ar c’heneil',
	'bouton_tout_compris_explication' => 'Ma anavezoc’h SPIP dija, e c’halloc’h divizout ober fae war holl kemenndoù ar c’heneil ; giz’all, pep kemenadenn a c’hall bezañ serret unan hag unan.',

	// C
	'c_accueil_bienvenue' => 'Degemer mat @nom@',
	'c_accueil_configurer_site' => 'Kefluniañ ho lec’h',
	'c_accueil_configurer_site_texte' => 'An dra gentañ d’ober eo reiñ un anv d’ho lec’hienn.
Bremañ ez eo anvet « @nom@ ». Dispaket eo an anv en nec’h d’ar bajenn-mañ.
En ur glikañ warnañ, e vo tu deoc’h kemmañ e anv, met ivez stagañ ul logo pe ul slogan warnañ.
		',
	'c_accueil_publication' => 'Embannit !',
	'c_accueil_publication_texte' => 'Evit embann ur bajenn e tleoc’h sevel ur pennad-skrid.
		Ret eo sevel ur rubrikenn d’an nebeutañ evit-se. Gallout a rit sevel unan e lañser "Embann" en ur klikañ war "Rubrikennoù".',
	'c_accueil_texte' => 'E lec’h prevez SPIP emaoc’h bremañ.',
	'c_accueil_texte_revenir' => '		Ar bajenn-mañ a ginnig ar pennadoù diwezhañ ho peus embannet war ho lec’h.
		Gallout a rit dont en-dro d’ar bajenn-mañ pep wech ho peus c’hoant en ur klikañ war ar skeuden "ti" a-hus, dindan hoc’h anv.
		',
	'c_article_redaction' => 'Ar pennad-mañ zo war-ober da skrivañ',
	'c_article_redaction_redacteur' => 'Ar pennad-mañ zo war-ober da skrivañ',
	'c_article_redaction_redacteur_texte' => 'Evit kinnig ho pennad-skrid da verourien ar lec’hienn ha d’ar re-all,
’barzh ar stern a gostez, kemmit « O skrivañ emer » gant « kinniget d’an embann ». ',
	'c_article_redaction_texte' => 'Evit embann ar pennad-mañ war al lec’h publik ret eo cheñch e statud.
		Er stern a-gostez chenchit "war-dro da skrivañ" en "embannet enlinenn".',
	'c_articles_creer' => 'Penaos krouiñ ur pennad-skrid ?',
	'c_articles_creer_texte' => 'Ne C’hallit ket krouiñ ur pennad-skrid er pajenn-mañ
		ma n’eus rubrikenn ebet en ho lec’h.
		Gallout a rit krouiñ anezhi el lañser "Embann", ha goude "Rubrikennoù" .',
	'c_job' => 'Labourioù da ober…',
	'c_job_texte' => 'Ar bajenn-mañ a sav roll al labourioù mererezh da vezañ kaset da benn gant SPIP. Al labourioù-maña vez a vez graet bep an amzer 
pe en un taol nemetken evit meriaduroù a-bouezh bet goulennet gant an astennoù plugin,
e-giz kas posteloù a-druilh-drast.',
	'c_rubrique_publier' => 'Krouit un embann skrid',
	'c_rubrique_publier_texte' => 'Ne vo gwelet ur rubrikenn war al lec’hienn foran
nemet pa vo  ur dra bennk embannet e-barzh ; dre skouer : ur pennad-skrid bet embannet.
Setu savit ur pennad-skrid. Tu zo en ober dre ar bajenn-mañ, dindan diskrivadenn ho rubrikenn.',
	'c_rubriques_creer' => 'Embannit ur rubrikenn gentañ !',
	'c_rubriques_creer_texte' => 'Framm al lec’h eo ar rubrikennoù ; galllout a rit krouiñ pennadoù-skrid e pep unan.
		Kinnig a rit krouiñ ur c’hentañ rubrikenn.',
	'c_sites_creer' => 'Penaos krouiñ pe enporzhiañ ul lec’h ?',
	'c_sites_creer_texte' => 'Ne c’hallit ket krouiñ pe enporzhiñ ul lec’h abaoe ar bajenn-mañ ma n’eus rubrikenn ebet en ho lec’h.
		Gallout a rit krouiñ anezhi el lañser "Embann", ha goude "Rubrikennoù".',

	// E
	'explication_activer_compagnon' => 'Ouzhpennañ a ra an ambrouger evezhiadennoù er pajennoù al lec’h prevez evit sikour ac’hanoc’h o implijout SPIP. Ezhomm hoc’h eus gweredekaet anezhañ ?',
	'explication_reinitialiser_compagnon' => 'Ne vez dispaket muioc’h ar gemenadennoù bet gwelet dija  gant un aozer.
C’hoant peus adkorañ ar gemenadennoù-se ?',

	// L
	'label_activer_compagnon' => 'Gweredekaat an ambrouger ?',
	'label_reinitialiser_compagnon' => 'Adreizhañ kannadoù an ambrouger ?',

	// O
	'ok' => 'Mat eo',
	'ok_bien' => 'Mat eo !',
	'ok_jai_compris' => 'komprennet em meus !',
	'ok_merci' => 'Trugarez',
	'ok_parfait' => 'Mat tre !',

	// R
	'reinitialisation' => 'Adkoradur',
	'reinitialisation_ok' => 'Echu eo an adkoradur.',
	'reinitialiser' => 'Adreizhet',
	'reinitialiser_moi' => 'Ya nemedken re meus dija lennet',
	'reinitialiser_tous' => 'Ya, sort pe sort vefe an aoser',

	// T
	'titre_compagnon' => 'An Ambrouger',
	'titre_page_configurer_compagnon' => 'Kefluniañ an Ambrouger',
];
